![ilexconf](https://raw.githubusercontent.com/vduseev/ilexconf/master/docs/img/logo.png)

<h2 align="center">Configuration Library for Python</h2>

<p align="center">
<a href="https://travis-ci.org/vduseev/ilexconf"><img alt="Build Status" src="https://travis-ci.org/vduseev/ilexconf.svg?branch=master"></a>
<a href="https://coveralls.io/github/psf/black?branch=master"><img alt="Coverage Status" src="https://coveralls.io/repos/github/psf/black/badge.svg?branch=master"></a>
<a href="https://github.com/psf/black/blob/master/LICENSE"><img alt="License: MIT" src="https://black.readthedocs.io/en/stable/_static/license.svg"></a>
<a href="https://pypi.org/project/black/"><img alt="PyPI" src="https://img.shields.io/pypi/v/black"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

## Features

## Quick Start

## Alternatives

| Library                           | Holly | Dynaconf |
| --------------------------------- | ----- | -------- |
| **Read from `.json`**             | x     | x        |
| **Read from `.toml`**             | x     | x        |
| **Read from `.ini`**              | x     | x        |
| **Read from env vars**            | x     | x        |
| **Read from `.py`**               |       | x        |
| **Read from `.env`**              |       | x        |
| **Read from dict object**         | x     |          |
| **Read from Redis**               |       | x        |
| **Read from Hashicorp Vault**     |       | x        |
| **Default values**                | x     | x        |         
| **Multienvironment**              |       | x        |
| **Attribute access**              | x     | x        |
| **Dotted key access**             | x     | x        |
| **Merging**                       | x     | onelevel |
| **Interpolation**                 |       | x        |
| **Saving**                        | x     | x        |
| **CLI**                           | x     | x        |
| **Printing**                      | x     | x        |
| **Validators**                    |       | x        |
| **Masking sensitive info**        |       | x        |
| **Django integration**            |       | x        |
| **Flask integration**             |       | x        |
| **Hot reload**                    |       |          |
| *Python 3.6*                      |       |          |
| *Python 3.7*                      |       |          |
| *Python 3.8*                      | x     |          |

## Kudos

`ilexconf` heavily borrows from `python-configuration` library and is inspired by it.

## License

MIT